<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="xml" omit-xml-declaration="yes" indent="no" />

    <xsl:include href="../../Commenting/XSL/CaptchaDiv.xsl"/>

    <xsl:template match="/" mode="WorkstationView">
        <b>Form Data</b>
        <br />
        <hr />
        <xsl:apply-templates select="/Block/BlockData/Elements/FormEditor/FormData"/>
        <hr />
        <b>Follow-up Data</b>
        <br />
        <hr />
        <xsl:apply-templates select="/Block/BlockData/Elements/FormEditor/ThankYouData" />
    </xsl:template>

    <xsl:template match="/" mode="EditForm">
        <xsl:param name="CaptchaData" />
        <xsl:param name="CaptchaActive" />
        <xsl:param name="DocID" />
        <xsl:param name="SourceDocID" />
        <xsl:param name="HoneypotName" />

        <xsl:variable name="UseCaptcha" >
            <xsl:choose>
                <xsl:when test="(/Block/BlockData/Elements/FormEditor/UseCaptcha=1 and /Block/BlockData/Elements/FormEditor/SubmitAction='ajax') or (/Block/BlockData/Elements/FormEditor/UseCaptchaPost=1 and /Block/BlockData/Elements/FormEditor/SubmitAction='post')">1</xsl:when>
                <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <div id="DataDiv_{/Block/@BlockID}" blockID="{/Block/@BlockID}">
            <div id="cmsFormsControl_ProcessingKey" key="{$HoneypotName}" style="display:none"><xsl:comment>placeholder</xsl:comment></div>
            <div width="98%" class="ErrorMessage" id="VerifyMessage_{/Block/@BlockID}" style="display:none">
                Please review the information below.  If everything is correct, click “Send”.  To go back and edit your entries, click “Edit”. 
            </div>
            <div class="ErrorMessage" id="cmsForms_DataNotProvided_{/Block/@BlockID}" style="display:none">
                The following required items were not provided or are in the wrong format.  Please provide the required responses and submit again:<br /><br />
            </div>
            <xsl:apply-templates select="/Block/BlockData/Elements/FormEditor/FormData"/>
            <xsl:if test="$CaptchaActive=1 and $UseCaptcha=1">
                <script>
                    // <![CDATA[
            var RecaptchaOptions = {
            theme: 'custom',
            lang: 'en',
            custom_theme_widget: 'cmsForms_TitanRatingReCaptchaZone'
            };
            // ]]>
                </script>
                <input type="hidden" id="TitanRecaptchaPublicKey" name="TitanRecaptchaPublicKey" value="{$CaptchaData/PublicKey}" />
                <xsl:call-template name="AddCaptchaDiv" >
                    <xsl:with-param name="PublicKey" select="$CaptchaData/PublicKey" />
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$DocID != $SourceDocID">
                <input type="hidden" id="cmsForms_SourceDocID" name="cmsForms_SourceDocID" value="{$SourceDocID}" />
            </xsl:if>
	        <div class="buttons" id="SubmitButtons_{/Block/@BlockID}" style="display:none">
                <input type="button" id="formSubmit{/Block/@BlockID}" value="Submit" onclick="javascript:SFSubmitForm('{$DocID}', '{/Block/@BlockID}', '{/Block/BlockData/Elements/FormEditor/DoConfirm}', '{$UseCaptcha}', '{/Block/BlockData/Elements/FormEditor/SubmitAction}');" class="formBlockSubmit"/>
            </div>
            <div class="buttons" id="ConfirmButtons_{/Block/@BlockID}" style="display:none">
                <input type="button" value="Send" onclick="javascript:SFFinalFormSubmit('{$DocID}', '{/Block/@BlockID}', '{$UseCaptcha}', '{/Block/BlockData/Elements/FormEditor/SubmitAction}');" class="formBlockSubmit"/>&#160;
                <input type="button" onclick="javascript:SFReturnToEdit('{/Block/@BlockID}');" value="Edit" class="formBlockEdit"/>
            </div>

            <script type="text/javascript">
                <xsl:variable name="BlockID" select="/Block/@BlockID" />
                <xsl:if test="$FormData/*/*">
                    <xsl:apply-templates select="$FormData/*/*" mode="SetPriorValues">
                        <xsl:with-param name="BlockID" select="$BlockID" />
                    </xsl:apply-templates>
                </xsl:if>
                <xsl:if test="$StyleNode/OnloadFunction">
                    if (window['<xsl:value-of select="$StyleNode/OnloadFunction"/>'])
                        window['<xsl:value-of select="$StyleNode/OnloadFunction"/>'](<xsl:value-of select="/Block/@BlockID"/>);
                </xsl:if>
                if (!document.getElementById("cmsForms_submitUDF"))
                    document.getElementById("SubmitButtons_<xsl:value-of select="/Block/@BlockID" />").style.display = "block";
            </script>
        </div>
        <xsl:choose>
            <xsl:when test="/Block/BlockData/Elements/FormEditor/SubmitAction='ajax'">
                <xsl:choose>
                    <xsl:when test="/Block/BlockData/Elements/FormEditor/PostSubmit='text'">
                        <div id="ThankYouDiv_{/Block/@BlockID}" style="display:none;">
                            <xsl:apply-templates select="/Block/BlockData/Elements/FormEditor/ThankYouData" />&#160;
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <input type="hidden" id="followupUrl_{/Block/@BlockID}" value="{/Block/BlockData/Elements/FormEditor/FollowupURL}" />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="/Block/BlockData/Elements/FormEditor/SubmitAction='remotePost'">
                <input type="hidden" id="postURL_{/Block/@BlockID}" value="{/Block/BlockData/Elements/FormEditor/AltURL}" />
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="*[name()='ErrorState']" mode="SetPriorValues">
        <xsl:param name="BlockID" />
        SFRespondToValidation(false, "formsubmit", "<xsl:value-of select="." />", "foo", '<xsl:value-of select="$BlockID"/>') ;
    </xsl:template>
    
    <xsl:template match="*" mode="SetPriorValues">
        <xsl:variable name="targetName">
            <xsl:choose>
                <xsl:when test="@UseInSubject=1">
                    <xsl:value-of select="concat('cmsFormS_', name())"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat('cmsForms_', name())"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        SFSetControlValue("<xsl:value-of select="$targetName"/>", "<xsl:call-template name="ConvertNewLines"><xsl:with-param name="text" select="."/></xsl:call-template>", false) ;
    </xsl:template>

    <xsl:template match="FormData">
        <xsl:value-of select="." disable-output-escaping="yes"/>
    </xsl:template>

    <xsl:template match="ThankYouData">
        <xsl:value-of select="." disable-output-escaping="yes"/>
    </xsl:template>

    <xsl:template match="text()"/>

    <!-- ********************** GENERAL PURPOSE STRING MANIPULATION ***************************** -->

	<!-- converts linefeed to JavaScript compatible '\n's -->
	<xsl:template name="ConvertNewLines">
		<xsl:param name="text"/>
        <!-- first step is remove all <cr>'s (0xd) -->
        <xsl:call-template name="ConvertNewLinesStep2">
            <xsl:with-param name="text" select="translate($text,'&#xd;','')"/>
        </xsl:call-template>
    </xsl:template>

	<xsl:template name="ConvertNewLinesStep2">
		<xsl:param name="text"/>
		<xsl:choose>
			<xsl:when test="contains($text, '&#xa;')">
			    <xsl:value-of select="substring-before($text, '&#xa;')"/>
			    <xsl:value-of select="'\n'"/>
			    <xsl:call-template name="ConvertNewLinesStep2">
				    <xsl:with-param name="text" select="substring-after($text,'&#xa;')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

    <!-- general purpose string substitution template -->
	<xsl:template name="strsubst">
		<xsl:param name="text"/>
		<xsl:param name="replace"/>
		<xsl:param name="with"/>
		<xsl:param name="disable-output-escaping">no</xsl:param>
		<xsl:choose>
			<xsl:when test="string-length($replace) = 0 and $disable-output-escaping = 'yes'">
				<xsl:value-of select="$text" disable-output-escaping="yes"/>
			</xsl:when>
			<xsl:when test="string-length($replace) = 0">
				<xsl:value-of select="$text"/>
			</xsl:when>
			<xsl:when test="contains($text, $replace)">
				<xsl:variable name="before" select="substring-before($text, $replace)"/>
				<xsl:variable name="after" select="substring-after($text, $replace)"/>
				<xsl:choose>
					<xsl:when test='$disable-output-escaping = "yes"'>
						<xsl:value-of select="$before" disable-output-escaping="yes"/>
						<xsl:value-of select="$with" disable-output-escaping="yes"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$before"/>
						<xsl:value-of select="$with"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="strsubst">
					<xsl:with-param name="text" select="$after"/>
					<xsl:with-param name="replace" select="$replace"/>
					<xsl:with-param name="with" select="$with"/>
					<xsl:with-param name="disable-output-escaping" select="$disable-output-escaping"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test='$disable-output-escaping = "yes"'>
				<xsl:value-of select="$text" disable-output-escaping="yes"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>